<?php
/**
 * @package	StarShop for Joomla!
 * @version	1.0.9
 * @author	joomstar.ir
 * @copyright	(C) 2012-2020 JOOMSTAR.IR SOFTWARE. All rights reserved.
 * @license	GNU/GPLv3 https://www.gnu.org/licenses/gpl-3.0.en.html
 */
defined('JPATH_BASE') or die;

class JFormFieldModal_Products extends JFormField
{
    protected $type = 'Modal_Products';

    protected function getInput()
    {
        $allowEdit = ((string)$this->element['edit'] == 'true') ? true : false;
        $allowClear = ((string)$this->element['clear'] != 'false') ? true : false;


        // Build the script.
        $script = array();

        // Select button script
        $script[] = '	function jSelectProduct_' . $this->id . '(id, title, object) {';
        $script[] = '		document.getElementById("' . $this->id . '_id").value = id;';
        $script[] = '		document.getElementById("' . $this->id . '_name").value = title;';
        $script[] = '		jQuery("#modalProducts' . $this->id . '").modal("hide");';

        if ($this->required) {
            $script[] = '		document.formvalidator.validate(document.getElementById("' . $this->id . '_id"));';
            $script[] = '		document.formvalidator.validate(document.getElementById("' . $this->id . '_name"));';
        }

        $script[] = '	}';

        // Clear button script
        static $scriptClear;

        if ($allowClear && !$scriptClear) {
            $scriptClear = true;

            $script[] = '	function jClearProduct(id) {';
            $script[] = '		document.getElementById(id + "_id").value = "";';
            $script[] = '		document.getElementById(id + "_name").value = "' .
                htmlspecialchars(JText::_('COM_JSTAR_SHOP_SELECT_AN_PRODUCT', true), ENT_COMPAT, 'UTF-8') . '";';
            $script[] = '		jQuery("#"+id + "_clear").addClass("hidden");';
            $script[] = '		if (document.getElementById(id + "_edit")) {';
            $script[] = '			jQuery("#"+id + "_edit").addClass("hidden");';
            $script[] = '		}';
            $script[] = '		return false;';
            $script[] = '	}';
        }

        // Add the script to the document head.
        JFactory::getDocument()->addScriptDeclaration(implode("\n", $script));

        // Setup variables for display.
        $html = array();
        $link = 'index.php?option=com_jstar_shop&amp;view=products&amp;layout=modal&amp;tmpl=component&amp;function=jSelectProduct_' . $this->id;


        if ((int)$this->value > 0) {
            $db = JFactory::getDbo();
            $query = $db->getQuery(true)
                ->select($db->quoteName('title'))
                ->from($db->quoteName('#__jstar_shop_products'))
                ->where($db->quoteName('id') . ' = ' . (int)$this->value);
            $db->setQuery($query);

            try {
                $title = $db->loadResult();
            } catch (RuntimeException $e) {
                JFactory::getApplication()->enqueueMessage($e->getMessage(), 'Warning');
            }
        }

        if (empty($title)) {
            $title = JText::_('COM_JSTAR_SHOP_SELECT_AN_PRODUCT');
        }
        $title = htmlspecialchars($title, ENT_QUOTES, 'UTF-8');

        // The active article id field.
        if (0 == (int)$this->value) {
            $value = '';
        } else {
            $value = (int)$this->value;
        }

        $url = $link . '&amp;' . JSession::getFormToken() . '=1';

        // The current article display field.
        $html[] = '<span class="input-append">';
        $html[] = '<input type="text" class="input-medium" id="' . $this->id . '_name" value="' . $title . '" disabled="disabled" size="35" />';
        $html[] = '<a href="#modalProducts' . $this->id . '" class="btn hasTooltip" role="button"  data-toggle="modal" title="'
            . JHtml::tooltipText('COM_JSTAR_SHOP_CHANGE_PRODUCT') . '">'
            . '<span class="icon-file"></span> '
            . JText::_('JSELECT') . '</a>';

        // Edit article button
        if ($allowEdit) {
            $html[] = '<a class="btn hasTooltip' . ($value ? '' : ' hidden')
                . '" href="index.php?option=com_jstar_shop&layout=modal&tmpl=component&task=product.edit&id=' . $value . '" target="_blank" title="'
                . JHtml::tooltipText('COM_JSTAR_SHOP_EDIT_PRODUCT') . '" ><span class="icon-edit"></span>' . JText::_('JACTION_EDIT') . '</a>';
        }

        // Clear article button
        if ($allowClear) {
            $html[] = '<button id="' . $this->id . '_clear" class="btn' . ($value ? '' : ' hidden') . '" onclick="return jClearProduct(\'' .
                $this->id . '\')"><span class="icon-remove"></span>' . JText::_('JCLEAR') . '</button>';
        }

        $html[] = '</span>';

        // The class='required' for client side validation
        $class = '';

        if ($this->required) {
            $class = ' class="required modal-value"';
        }

        $html[] = '<input type="hidden" id="' . $this->id . '_id"' . $class . ' name="' . $this->name . '" value="' . $value . '" />';

        $html[] = JHtml::_(
            'bootstrap.renderModal',
            'modalProducts' . $this->id,
            array(
                'url' => $url,
                'title' => JText::_('COM_JSTAR_SHOP_CHANGE_PRODUCT'),
                'width' => '800px',
                'height' => '300px',
                'footer' => '<button class="btn" data-dismiss="modal" aria-hidden="true">'
                    . JText::_("JLIB_HTML_BEHAVIOR_CLOSE") . '</button>'
            )
        );
        return implode("\n", $html);
    }

    /**
     * Method to get the field label markup.
     *
     * @return  string  The field label markup.
     *
     * @since   3.4
     */
    protected function getLabel()
    {
        return str_replace($this->id, $this->id . '_id', parent::getLabel());
    }
}
